==> haskell-binary-conduit-1.2.5-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.2.5
id: binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
key: binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
author: Alexander Vershilov
exposed: True
indefinite: False
exposed-modules:
    Data.Conduit.Serialization.Binary
abi: 263ddc01c9f4ff96f7e103f83c45d2b4
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/binary-conduit-1.2.5
hs-libraries: HSbinary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
depends:
    base-4.10.0.0 conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=3708573cd3ea293480bf7666534b0844
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.2.5-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.2.5
id: binary-conduit-1.2.5-31EyZVzgu87DUNvMVFKqfl
key: binary-conduit-1.2.5-31EyZVzgu87DUNvMVFKqfl
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
author: Alexander Vershilov
exposed: True
indefinite: False
exposed-modules:
    Data.Conduit.Serialization.Binary
abi: df60fea5947700438459ba09964ee32f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/binary-conduit-1.2.5
hs-libraries: HSbinary-conduit-1.2.5-31EyZVzgu87DUNvMVFKqfl
depends:
    base-4.10.0.0 conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             binary-0.8.5.1=44e4c28d2f38593047e3772473ecb87e
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
